<html><h1>
    <!-- Here goes the code after submitting the form, 
    in order to steal credentials, we must add 'form' tag with 
    'username', 'password', 'submit' tags to the index.html file -->
    Hello! 
</h1></html>